package epson.print.copy.Component.ecopycomponent;

import android.os.AsyncTask;

import java.util.ArrayList;

import epson.print.copy.Component.eremoteoperation.ERemoteCopy;
import epson.print.copy.Component.eremoteoperation.ERemoteCopyPhoto;
import epson.print.copy.Component.eremoteoperation.ERemoteOperation;
import epson.print.copy.Component.eremoteoperation.ERemotePrinter;

class RemoteCopyPhotoTask extends AsyncTask<Void, Progress, Result> implements ECopyComponent.ITask {
    ERemoteCopy.IRemoteCancelParameter cancelParameter;
    boolean cancelRequested;
    String clientID;
    String jobToken;
    ERemoteCopyPhoto operation = new ERemoteCopyPhoto();
    ECopyOptionContext optionContext;
    CopyPhotoSettingHandler photoSetting;
    Progress progress = new Progress();
    ECopyComponent.ICopyStatusListener statusListener;
    ERemoteCopy.IRemoteCopyStatusParameter statusParameter;
    ECopyComponent.ICopySystemSettings systemSettings;

    class Progress {
        int currentPages;
        ECopyComponent.ICopyInvalidateResumeRequest resumeRequest;
        ECopyComponent.ICopyResumeRequest.ResumeState resumeState;
        ECopyComponent.ICopyStatusListener.CopyTaskProgress taskProgress;
        int totalPages;

        Progress() {
        }
    }

    class Result {
        ECopyComponent.ICopyStatusListener.CopyTaskResult taskResult;

        private void setResult(ERemoteOperation.ERemoteParam eRemoteParam) {
            switch (eRemoteParam) {
                case none:
                    taskResult = ECopyComponent.ICopyStatusListener.CopyTaskResult.Succeed;
                    return;
                case success:
                    taskResult = ECopyComponent.ICopyStatusListener.CopyTaskResult.Succeed;
                    return;
                case canceled:
                    taskResult = ECopyComponent.ICopyStatusListener.CopyTaskResult.Canceled;
                    return;
                case busy:
                    taskResult = ECopyComponent.ICopyStatusListener.CopyTaskResult.Busy;
                    return;
                case document_error:
                    taskResult = ECopyComponent.ICopyStatusListener.CopyTaskResult.ErrorOther;
                    return;
                case x_failed_communication:
                    taskResult = ECopyComponent.ICopyStatusListener.CopyTaskResult.ErrorCommunication;
                    return;
                case unknown_token:
                    taskResult = ECopyComponent.ICopyStatusListener.CopyTaskResult.ErrorOther;
                    return;
                case x_invalid_photo_setting:
                    taskResult = ECopyComponent.ICopyStatusListener.CopyTaskResult.ErrorInvalidOption;
                    return;
                default:
                    taskResult = ECopyComponent.ICopyStatusListener.CopyTaskResult.ErrorOther;
                    return;
            }
        }

        public Result(ERemoteOperation.ERemoteParam eRemoteParam) {
            setResult(eRemoteParam);
        }

        public Result(ERemoteOperation.ERemoteReasonResult eRemoteReasonResult) {
            if (eRemoteReasonResult.isNull(ERemoteOperation.ERemoteParam.success)) {
                setResult(ERemoteOperation.ERemoteParam.x_failed_communication);
            } else {
                setResult(eRemoteReasonResult.reason());
            }
        }
    }

    public RemoteCopyPhotoTask(String str, ECopyComponent.ICopyStatusListener iCopyStatusListener) {
        photoSetting = new CopyPhotoSettingHandler(str);
        statusListener = iCopyStatusListener;
    }

    public ECopyComponent.ICopyCancelRequest start() {
        super.execute(new Void[0]);
        return new ECopyComponent.ICopyCancelRequest() {
            public void cancel() {
                synchronized (this) {
                    cancelRequested = true;
                }
            }
        };
    }

    public void setSystemSettings(ECopyComponent.ICopySystemSettings iCopySystemSettings) {
        systemSettings = iCopySystemSettings;
    }

    public void setRequestConnectionTimeout(int i) {
        operation.setRequestConnectionTimeout(i);
    }

    public void setClientID(String str) {
        clientID = str;
    }

    public void setOptionContext(ECopyOptionContext eCopyOptionContext) {
        optionContext = eCopyOptionContext;
    }

    protected void onPreExecute() {
        cancelParameter = new ERemoteCopy.IRemoteCancelParameter() {
            public String client_id() {
                return clientID;
            }

            public String job_token() {
                return jobToken;
            }
        };
        statusParameter = new ERemoteCopy.IRemoteCopyStatusParameter() {
            public String client_id() {
                return clientID;
            }

            public String job_token() {
                return jobToken;
            }

            public ArrayList<ERemoteOperation.ERemoteParam> keys() {
                ArrayList<ERemoteOperation.ERemoteParam> arrayList = new ArrayList<>();
                arrayList.add(ERemoteOperation.ERemoteParam.print_x_disc_tray_state);
                arrayList.add(ERemoteOperation.ERemoteParam.printer_state);
                arrayList.add(ERemoteOperation.ERemoteParam.printer_state_reasons);
                arrayList.add(ERemoteOperation.ERemoteParam.scanner_state);
                arrayList.add(ERemoteOperation.ERemoteParam.scanner_state_reasons);
                arrayList.add(ERemoteOperation.ERemoteParam.job_state);
                arrayList.add(ERemoteOperation.ERemoteParam.job_result);
                arrayList.add(ERemoteOperation.ERemoteParam.job_tokens);
                arrayList.add(ERemoteOperation.ERemoteParam.job_print_total_pages);
                arrayList.add(ERemoteOperation.ERemoteParam.job_print_current_pages);
                return arrayList;
            }
        };
        statusListener.onStarted(ECopyComponent.ICopyStatusListener.CopyTaskType.Copy);
    }

    protected void onProgressUpdate(Progress... progressArr) {
        Progress progress2 = progressArr[0];
        statusListener.onProcessed(ECopyComponent.ICopyStatusListener.CopyTaskType.Copy, progress2.totalPages, progress2.currentPages, progress2.taskProgress, progress2.resumeRequest);
    }

    private void resumeNotify(ECopyComponent.ICopyResumeRequest.ResumeState resumeState) {
        synchronized (progress) {
            progress.resumeState = resumeState;
            progress.notify();
        }
    }

    private int resumeExecute() {
        int i = 1000;
        if (progress.resumeRequest == null) {
            return 1000;
        }
        synchronized (progress) {
            while (progress.resumeState == null) {
                try {
                    progress.wait(1000);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
        }
        switch (progress.resumeState) {
            case ClearError:
                ERemotePrinter eRemotePrinter = new ERemotePrinter();
                eRemotePrinter.setHostIP(operation.getHostIP());
                eRemotePrinter.setRequestConnectionTimeout(operation.getRequestConnectionTimeout());
                eRemotePrinter.clearError(new ERemoteOperation.IRemoteOperationParameter() {
                    public String client_id() {
                        return clientID;
                    }
                });
                i = 15000;
                break;
            case Cancel:
                cancelRequested = true;
                break;
        }
        Progress progress2 = progress;
        progress2.resumeState = null;
        progress2.resumeRequest = null;
        return i;
    }

    private ERemoteOperation.ERemoteReasonResult startCopy() {
        ERemoteCopy.ERemoteCopyResult copy = operation.copy(new ERemoteCopyPhoto.IRemoteCopyPhotoParameter() {
            public String client_id() {
                return clientID;
            }

            public ERemoteOperation.ERemoteParam layout() {
                return optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.XBorderless).getSelectedChoice().param;
            }

            public ERemoteOperation.ERemoteParam print_media_type() {
                return optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.PrintMediaType).getSelectedChoice().param;
            }

            public ERemoteOperation.ERemoteParam print_media_size() {
                return optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.PrintMediaSize).getSelectedChoice().param;
            }

            public ERemoteOperation.ERemoteParam print_quality() {
                return optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.PrintQuality).getSelectedChoice().param;
            }

            public ERemoteOperation.ERemoteParam print_media_source() {
                return optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.PrintMediaSource).getSelectedChoice().param;
            }

            public ERemoteOperation.ERemoteParam x_apf() {
                return optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.XApf).getSelectedChoice().param;
            }

            public ERemoteOperation.ERemoteParam x_color_restoration() {
                return optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.XColorRestoration).getSelectedChoice().param;
            }

            public ERemoteOperation.ERemoteParam color_effects_type() {
                return optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.ColorEffectsType).getSelectedChoice().param;
            }

            public int scan_count() {
                return photoSetting.getScanCount();
            }

            public ArrayList<String> copies() {
                return photoSetting.scanCopies;
            }

            public ArrayList<String> scan_area_x() {
                return photoSetting.scanAreaX;
            }

            public ArrayList<String> scan_area_y() {
                return photoSetting.scanAreaY;
            }

            public ArrayList<String> scan_area_width() {
                return photoSetting.scanAreaWidth;
            }

            public ArrayList<String> scan_area_height() {
                return photoSetting.scanAreaHeight;
            }

            public ArrayList<String> scan_area_resolution() {
                return photoSetting.scanAreaResolution;
            }

            public ERemoteOperation.ERemoteParam print_x_bleed() {
                if  (optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.XBorderless).getSelectedChoice().param == ERemoteOperation.ERemoteParam.standard) {
                    return ERemoteOperation.ERemoteParam.x_null;
                }
                return optionContext.getCopyOptionItemOf(ECopyOptionItem.ECopyOptionItemKey.PrintXBleed).getSelectedChoice().param;
            }

            public ERemoteOperation.ERemoteParam print_x_auto_pg() {
                return ERemoteOperation.ERemoteParam.off;
            }

            public ArrayList<String> x_fit_gamma() {
                return photoSetting.xFitGamma;
            }

            public ArrayList<String> x_fit_matrix() {
                return photoSetting.xFitMatrix;
            }
        });
        if (copy.success()) {
            jobToken = copy.job_token();
        }
        return copy;
    }

    protected Result doInBackground(Void... voidArr) {
        operation.setHostIP(systemSettings.getPrinterIPAddress());
        if (!photoSetting.parse()) {
            return new Result(ERemoteOperation.ERemoteParam.x_invalid_photo_setting);
        }
        ERemoteOperation.ERemoteReasonResult startCopy = startCopy();
        if (!startCopy.success()) {
            return new Result(startCopy);
        }
        Result result = null;
        boolean z = false;
        boolean z2 = false;
        while (!z) {
            if (cancelRequested && !z2) {
                if (!operation.cancel(cancelParameter).success()) {
                    return new Result(ERemoteOperation.ERemoteParam.canceled);
                }
                z2 = true;
            }
            final ERemoteCopy.ERemoteCopyStatusResult status = operation.getStatus(statusParameter);
            if (!status.success()) {
                return new Result((ERemoteOperation.ERemoteReasonResult) status);
            }
            Result result2 = new Result(status.job_result());
            progress.totalPages = status.job_print_total_pages();
            progress.currentPages = status.job_print_current_pages();
            if (progress.currentPages < 1) {
                progress.currentPages = 1;
            }
            ERemoteOperation.ERemoteParam job_state = status.job_state();
            switch (job_state) {
                case scanning:
                    progress.taskProgress = ECopyComponent.ICopyStatusListener.CopyTaskProgress.Scanning;
                    break;
                case copying:
                    progress.taskProgress = ECopyComponent.ICopyStatusListener.CopyTaskProgress.Copying;
                    break;
                case canceling:
                    progress.taskProgress = ECopyComponent.ICopyStatusListener.CopyTaskProgress.Canceling;
                    break;
                case finished:
                    result = result2;
                    z = true;
                    continue;
            }
            switch (status.printer_state()) {
                case stopped:
                    if (job_state == ERemoteOperation.ERemoteParam.copying || job_state == ERemoteOperation.ERemoteParam.scanning) {
                        Progress progress2 = progress;
                        progress2.resumeState = null;
                        progress2.taskProgress = ECopyComponent.ICopyStatusListener.CopyTaskProgress.Stopped;
                        progress.resumeRequest = new ECopyComponent.ICopyInvalidateResumeRequest() {
                            public void invalidate() {
                            }

                            public ECopyComponent.ICopyResumeRequest.StopReason getStopReason() {
                                ECopyComponent.ICopyResumeRequest.StopReason printerStopReason = RemoteCopyTask.getPrinterStopReason(status.printer_state_reasons());
                                return printerStopReason == ECopyComponent.ICopyResumeRequest.StopReason.None ? RemoteCopyTask.getScannerStopReason(status.scanner_state_reasons()) : printerStopReason;
                            }

                            public boolean isPossibleClearError() {
                                switch (C21897.f373xc6bf26c4[RemoteCopyTask.getPrinterStopReason(status.printer_state_reasons()).ordinal()]) {
                                    case 1:
                                        return false;
                                    case 2:
                                        return false;
                                    case 3:
                                        return false;
                                    case 4:
                                        return true;
                                    case 5:
                                        return true;
                                    case 6:
                                        return true;
                                    case 7:
                                        return true;
                                    case 8:
                                        return false;
                                    default:
                                        switch (C21897.f373xc6bf26c4[RemoteCopyTask.getScannerStopReason(status.scanner_state_reasons()).ordinal()]) {
                                            case 9:
                                                return false;
                                            case 10:
                                                return false;
                                            case 11:
                                                return false;
                                            case 12:
                                                return false;
                                            default:
                                                return false;
                                        }
                                }
                            }

                            public void resume(ECopyComponent.ICopyResumeRequest.ResumeState resumeState) {
                                progress.taskProgress = ECopyComponent.ICopyStatusListener.CopyTaskProgress.Processing;
                                RemoteCopyPhotoTask remoteCopyPhotoTask = RemoteCopyPhotoTask.this;
                                remoteCopyPhotoTask.publishProgress(new Progress[]{remoteCopyPhotoTask.progress});
                                resumeNotify(resumeState);
                            }
                        };
                        break;
                    }
            }
            publishProgress(new Progress[]{this.progress});
            try {
                Thread.sleep((long) resumeExecute());
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            result = result2;
        }
        return result;
    }

    /* renamed from: epson.print.copy.Component.ecopycomponent.RemoteCopyPhotoTask$7 */
    static /* synthetic */ class C21897 {

        /* renamed from: $SwitchMap$epson$print$copy$Component$ecopycomponent$ECopyComponent$ICopyResumeRequest$StopReason */
        static final /* synthetic */ int[] f373xc6bf26c4 = new int[ECopyComponent.ICopyResumeRequest.StopReason.values().length];

        /* JADX WARNING: Can't wrap try/catch for region: R(59:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|(2:13|14)|15|(2:17|18)|19|(2:21|22)|23|(2:25|26)|27|(2:29|30)|31|(2:33|34)|35|(2:37|38)|39|(2:41|42)|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(60:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|(2:13|14)|15|(2:17|18)|19|(2:21|22)|23|(2:25|26)|27|(2:29|30)|31|(2:33|34)|35|(2:37|38)|39|41|42|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(61:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|(2:13|14)|15|17|18|19|(2:21|22)|23|(2:25|26)|27|(2:29|30)|31|(2:33|34)|35|(2:37|38)|39|41|42|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(62:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|(2:13|14)|15|17|18|19|(2:21|22)|23|(2:25|26)|27|(2:29|30)|31|(2:33|34)|35|37|38|39|41|42|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(63:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|13|14|15|17|18|19|(2:21|22)|23|(2:25|26)|27|(2:29|30)|31|(2:33|34)|35|37|38|39|41|42|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(64:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|13|14|15|17|18|19|(2:21|22)|23|(2:25|26)|27|(2:29|30)|31|33|34|35|37|38|39|41|42|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(65:0|(2:1|2)|3|(2:5|6)|7|9|10|11|13|14|15|17|18|19|(2:21|22)|23|(2:25|26)|27|(2:29|30)|31|33|34|35|37|38|39|41|42|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(66:0|(2:1|2)|3|(2:5|6)|7|9|10|11|13|14|15|17|18|19|(2:21|22)|23|(2:25|26)|27|29|30|31|33|34|35|37|38|39|41|42|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(67:0|(2:1|2)|3|5|6|7|9|10|11|13|14|15|17|18|19|(2:21|22)|23|(2:25|26)|27|29|30|31|33|34|35|37|38|39|41|42|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(68:0|(2:1|2)|3|5|6|7|9|10|11|13|14|15|17|18|19|(2:21|22)|23|25|26|27|29|30|31|33|34|35|37|38|39|41|42|43|(2:45|46)|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|(3:83|84|86)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(72:0|1|2|3|5|6|7|9|10|11|13|14|15|17|18|19|(2:21|22)|23|25|26|27|29|30|31|33|34|35|37|38|39|41|42|43|45|46|47|49|50|51|52|53|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|83|84|86) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:51:0x00a5 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:57:0x00c2 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:59:0x00cc */
        /* JADX WARNING: Missing exception handler attribute for start block: B:61:0x00d6 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:63:0x00e0 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:65:0x00ea */
        /* JADX WARNING: Missing exception handler attribute for start block: B:67:0x00f4 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:69:0x00fe */
        /* JADX WARNING: Missing exception handler attribute for start block: B:71:0x0108 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:73:0x0112 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:75:0x011c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:77:0x0126 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:79:0x0130 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:81:0x013c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:83:0x0148 */
        static {
            /*
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason[] r0 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.values()
                int r0 = r0.length
                int[] r0 = new int[r0]
                f373xc6bf26c4 = r0
                r0 = 1
                int[] r1 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x0014 }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r2 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.PrinterMarkerSupplyEmptyError     // Catch:{ NoSuchFieldError -> 0x0014 }
                int r2 = r2.ordinal()     // Catch:{ NoSuchFieldError -> 0x0014 }
                r1[r2] = r0     // Catch:{ NoSuchFieldError -> 0x0014 }
            L_0x0014:
                r1 = 2
                int[] r2 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x001f }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r3 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.PrinterMarkerWasteFullError     // Catch:{ NoSuchFieldError -> 0x001f }
                int r3 = r3.ordinal()     // Catch:{ NoSuchFieldError -> 0x001f }
                r2[r3] = r1     // Catch:{ NoSuchFieldError -> 0x001f }
            L_0x001f:
                r2 = 3
                int[] r3 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x002a }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r4 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.PrinterMediaJamError     // Catch:{ NoSuchFieldError -> 0x002a }
                int r4 = r4.ordinal()     // Catch:{ NoSuchFieldError -> 0x002a }
                r3[r4] = r2     // Catch:{ NoSuchFieldError -> 0x002a }
            L_0x002a:
                r3 = 4
                int[] r4 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x0035 }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r5 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.PrinterMediaEmptyError     // Catch:{ NoSuchFieldError -> 0x0035 }
                int r5 = r5.ordinal()     // Catch:{ NoSuchFieldError -> 0x0035 }
                r4[r5] = r3     // Catch:{ NoSuchFieldError -> 0x0035 }
            L_0x0035:
                r4 = 5
                int[] r5 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x0040 }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r6 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.PrinterInputTrayMissingError     // Catch:{ NoSuchFieldError -> 0x0040 }
                int r6 = r6.ordinal()     // Catch:{ NoSuchFieldError -> 0x0040 }
                r5[r6] = r4     // Catch:{ NoSuchFieldError -> 0x0040 }
            L_0x0040:
                r5 = 6
                int[] r6 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x004b }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r7 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.PrinterCoverOpenError     // Catch:{ NoSuchFieldError -> 0x004b }
                int r7 = r7.ordinal()     // Catch:{ NoSuchFieldError -> 0x004b }
                r6[r7] = r5     // Catch:{ NoSuchFieldError -> 0x004b }
            L_0x004b:
                r6 = 7
                int[] r7 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x0056 }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r8 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.PrinterOutputAreaFullError     // Catch:{ NoSuchFieldError -> 0x0056 }
                int r8 = r8.ordinal()     // Catch:{ NoSuchFieldError -> 0x0056 }
                r7[r8] = r6     // Catch:{ NoSuchFieldError -> 0x0056 }
            L_0x0056:
                r7 = 8
                int[] r8 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x0062 }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r9 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.PrinterOtherError     // Catch:{ NoSuchFieldError -> 0x0062 }
                int r9 = r9.ordinal()     // Catch:{ NoSuchFieldError -> 0x0062 }
                r8[r9] = r7     // Catch:{ NoSuchFieldError -> 0x0062 }
            L_0x0062:
                r8 = 9
                int[] r9 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x006e }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r10 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.ScannerMediaEmptyError     // Catch:{ NoSuchFieldError -> 0x006e }
                int r10 = r10.ordinal()     // Catch:{ NoSuchFieldError -> 0x006e }
                r9[r10] = r8     // Catch:{ NoSuchFieldError -> 0x006e }
            L_0x006e:
                r9 = 10
                int[] r10 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x007a }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r11 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.ScannerMediaJamError     // Catch:{ NoSuchFieldError -> 0x007a }
                int r11 = r11.ordinal()     // Catch:{ NoSuchFieldError -> 0x007a }
                r10[r11] = r9     // Catch:{ NoSuchFieldError -> 0x007a }
            L_0x007a:
                r10 = 11
                int[] r11 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x0086 }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r12 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.ScannerMediaSizeMissmatchError     // Catch:{ NoSuchFieldError -> 0x0086 }
                int r12 = r12.ordinal()     // Catch:{ NoSuchFieldError -> 0x0086 }
                r11[r12] = r10     // Catch:{ NoSuchFieldError -> 0x0086 }
            L_0x0086:
                r11 = 12
                int[] r12 = f373xc6bf26c4     // Catch:{ NoSuchFieldError -> 0x0092 }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$StopReason r13 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.StopReason.ScannerOtherError     // Catch:{ NoSuchFieldError -> 0x0092 }
                int r13 = r13.ordinal()     // Catch:{ NoSuchFieldError -> 0x0092 }
                r12[r13] = r11     // Catch:{ NoSuchFieldError -> 0x0092 }
            L_0x0092:
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$ResumeState[] r12 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.ResumeState.values()
                int r12 = r12.length
                int[] r12 = new int[r12]
                f372x17ee3246 = r12
                int[] r12 = f372x17ee3246     // Catch:{ NoSuchFieldError -> 0x00a5 }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$ResumeState r13 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.ResumeState.ClearError     // Catch:{ NoSuchFieldError -> 0x00a5 }
                int r13 = r13.ordinal()     // Catch:{ NoSuchFieldError -> 0x00a5 }
                r12[r13] = r0     // Catch:{ NoSuchFieldError -> 0x00a5 }
            L_0x00a5:
                int[] r12 = f372x17ee3246     // Catch:{ NoSuchFieldError -> 0x00af }
                epson.print.copy.Component.ecopycomponent.ECopyComponent$ICopyResumeRequest$ResumeState r13 = epson.print.copy.Component.ecopycomponent.ECopyComponent.ICopyResumeRequest.ResumeState.Cancel     // Catch:{ NoSuchFieldError -> 0x00af }
                int r13 = r13.ordinal()     // Catch:{ NoSuchFieldError -> 0x00af }
                r12[r13] = r1     // Catch:{ NoSuchFieldError -> 0x00af }
            L_0x00af:
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam[] r12 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.values()
                int r12 = r12.length
                int[] r12 = new int[r12]
                f374xed9088c4 = r12
                int[] r12 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x00c2 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r13 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.none     // Catch:{ NoSuchFieldError -> 0x00c2 }
                int r13 = r13.ordinal()     // Catch:{ NoSuchFieldError -> 0x00c2 }
                r12[r13] = r0     // Catch:{ NoSuchFieldError -> 0x00c2 }
            L_0x00c2:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x00cc }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r12 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.success     // Catch:{ NoSuchFieldError -> 0x00cc }
                int r12 = r12.ordinal()     // Catch:{ NoSuchFieldError -> 0x00cc }
                r0[r12] = r1     // Catch:{ NoSuchFieldError -> 0x00cc }
            L_0x00cc:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x00d6 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.canceled     // Catch:{ NoSuchFieldError -> 0x00d6 }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x00d6 }
                r0[r1] = r2     // Catch:{ NoSuchFieldError -> 0x00d6 }
            L_0x00d6:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x00e0 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.busy     // Catch:{ NoSuchFieldError -> 0x00e0 }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x00e0 }
                r0[r1] = r3     // Catch:{ NoSuchFieldError -> 0x00e0 }
            L_0x00e0:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x00ea }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.document_error     // Catch:{ NoSuchFieldError -> 0x00ea }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x00ea }
                r0[r1] = r4     // Catch:{ NoSuchFieldError -> 0x00ea }
            L_0x00ea:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x00f4 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.x_failed_communication     // Catch:{ NoSuchFieldError -> 0x00f4 }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x00f4 }
                r0[r1] = r5     // Catch:{ NoSuchFieldError -> 0x00f4 }
            L_0x00f4:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x00fe }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.unknown_token     // Catch:{ NoSuchFieldError -> 0x00fe }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x00fe }
                r0[r1] = r6     // Catch:{ NoSuchFieldError -> 0x00fe }
            L_0x00fe:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x0108 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.x_invalid_photo_setting     // Catch:{ NoSuchFieldError -> 0x0108 }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x0108 }
                r0[r1] = r7     // Catch:{ NoSuchFieldError -> 0x0108 }
            L_0x0108:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x0112 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.scanning     // Catch:{ NoSuchFieldError -> 0x0112 }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x0112 }
                r0[r1] = r8     // Catch:{ NoSuchFieldError -> 0x0112 }
            L_0x0112:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x011c }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.copying     // Catch:{ NoSuchFieldError -> 0x011c }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x011c }
                r0[r1] = r9     // Catch:{ NoSuchFieldError -> 0x011c }
            L_0x011c:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x0126 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.canceling     // Catch:{ NoSuchFieldError -> 0x0126 }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x0126 }
                r0[r1] = r10     // Catch:{ NoSuchFieldError -> 0x0126 }
            L_0x0126:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x0130 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.finished     // Catch:{ NoSuchFieldError -> 0x0130 }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x0130 }
                r0[r1] = r11     // Catch:{ NoSuchFieldError -> 0x0130 }
            L_0x0130:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x013c }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.idle     // Catch:{ NoSuchFieldError -> 0x013c }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x013c }
                r2 = 13
                r0[r1] = r2     // Catch:{ NoSuchFieldError -> 0x013c }
            L_0x013c:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x0148 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.processing     // Catch:{ NoSuchFieldError -> 0x0148 }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x0148 }
                r2 = 14
                r0[r1] = r2     // Catch:{ NoSuchFieldError -> 0x0148 }
            L_0x0148:
                int[] r0 = f374xed9088c4     // Catch:{ NoSuchFieldError -> 0x0154 }
                epson.print.copy.Component.eremoteoperation.ERemoteOperation$ERemoteParam r1 = epson.print.copy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.stopped     // Catch:{ NoSuchFieldError -> 0x0154 }
                int r1 = r1.ordinal()     // Catch:{ NoSuchFieldError -> 0x0154 }
                r2 = 15
                r0[r1] = r2     // Catch:{ NoSuchFieldError -> 0x0154 }
            L_0x0154:
                return
            */
            throw new UnsupportedOperationException("Method not decompiled: epson.print.copy.Component.ecopycomponent.RemoteCopyPhotoTask.C21897.<clinit>():void");
        }
    }

    protected void onPostExecute(Result result) {
        statusListener.onFinished(ECopyComponent.ICopyStatusListener.CopyTaskType.Copy, result.taskResult);
    }
}
