package epson.print.rpcopy.Component.ecopycomponent;

import android.os.Parcel;
import android.os.Parcelable;

import java.util.ArrayList;
import java.util.Iterator;

import epson.print.rpcopy.Component.eremoteoperation.ERemoteCopy;
import epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation;

public class ECopyOptionItem implements Parcelable {
    public static final Parcelable.Creator<ECopyOptionItem> CREATOR = new Parcelable.Creator<ECopyOptionItem>() {
        public ECopyOptionItem createFromParcel(Parcel parcel) {
            return new ECopyOptionItem(parcel);
        }

        public ECopyOptionItem[] newArray(int i) {
            return new ECopyOptionItem[i];
        }
    };
    public static int CopyMagnificationAutofitValue = -999;
    static int DefaultExceptionValue = -10000;
    ChoiceArray choiceArray;
    ECopyOptionItemChoiceType choiceType;
    boolean enabled;
    boolean isLocalOption;
    ECopyOptionItemKey key;
    NumberRange numberRange;

    public enum ECopyOptionItemChoiceType {
        ChoiceArray,
        NumberRange
    }

    public int describeContents() {
        return 0;
    }

    class ChoiceArray {
        ArrayList<ECopyOptionItemChoice> choices = new ArrayList<>();
        int defaultChoice;
        int selectedChoice;

        public ChoiceArray() {
        }

        public ChoiceArray(ChoiceArray choiceArray) {
            Iterator<ECopyOptionItemChoice> it = choiceArray.choices.iterator();
            while (it.hasNext()) {
                choices.add(it.next());
            }
            selectedChoice = choiceArray.selectedChoice;
            defaultChoice = choiceArray.defaultChoice;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof ChoiceArray)) {
                return false;
            }
            ChoiceArray choiceArray = (ChoiceArray) obj;
            if (selectedChoice != choiceArray.selectedChoice || defaultChoice != choiceArray.defaultChoice || choices.size() != choiceArray.choices.size()) {
                return false;
            }
            for (int i = 0; i < choices.size(); i++) {
                if (choices.get(i) != choiceArray.choices.get(i)) {
                    return false;
                }
            }
            return true;
        }
    }

    class NumberRange {
        int defaultValue;
        int exceptionValue;
        int max;
        int min;
        int selectedValue;

        public NumberRange() {
        }

        public NumberRange(NumberRange numberRange) {
            min = numberRange.min;
            max = numberRange.max;
            selectedValue = numberRange.selectedValue;
            defaultValue = numberRange.defaultValue;
            exceptionValue = numberRange.exceptionValue;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof NumberRange)) {
                return false;
            }
            NumberRange numberRange = (NumberRange) obj;
            if (min == numberRange.min && max == numberRange.max && selectedValue == numberRange.selectedValue && defaultValue == numberRange.defaultValue && exceptionValue == numberRange.exceptionValue) {
                return true;
            }
            return false;
        }
    }

    public void writeToParcel(Parcel parcel, int i) {
        parcel.writeString(key.name());
        parcel.writeString(choiceType.name());
        parcel.writeInt(enabled ? 1 : 0);
        parcel.writeInt(isLocalOption ? 1 : 0);
        if (choiceType == ECopyOptionItemChoiceType.ChoiceArray) {
            parcel.writeInt(choiceArray.choices.size());
            Iterator<ECopyOptionItemChoice> it = choiceArray.choices.iterator();
            while (it.hasNext()) {
                parcel.writeString(it.next().param.name());
            }
            parcel.writeInt(choiceArray.selectedChoice);
            parcel.writeInt(choiceArray.defaultChoice);
            return;
        }
        parcel.writeInt(numberRange.min);
        parcel.writeInt(numberRange.max);
        parcel.writeInt(numberRange.selectedValue);
        parcel.writeInt(numberRange.defaultValue);
        parcel.writeInt(numberRange.exceptionValue);
    }

    ECopyOptionItem(Parcel parcel) {
        key = ECopyOptionItemKey.valueOf(parcel.readString());
        choiceType = ECopyOptionItemChoiceType.valueOf(parcel.readString());
        boolean z = true;
        enabled = parcel.readInt() == 1;
        isLocalOption = parcel.readInt() != 1 ? false : z;
        if (choiceType == ECopyOptionItemChoiceType.ChoiceArray) {
            choiceArray = new ChoiceArray();
            int readInt = parcel.readInt();
            for (int i = 0; i < readInt; i++) {
                choiceArray.choices.add(ECopyOptionItemChoice.valueOf(key, ERemoteOperation.ERemoteParam.valueOf(parcel.readString())));
            }
            choiceArray.selectedChoice = parcel.readInt();
            choiceArray.defaultChoice = parcel.readInt();
            return;
        }
        numberRange = new NumberRange();
        numberRange.min = parcel.readInt();
        numberRange.max = parcel.readInt();
        numberRange.selectedValue = parcel.readInt();
        numberRange.defaultValue = parcel.readInt();
        numberRange.exceptionValue = parcel.readInt();
    }

    ECopyOptionItem(ECopyOptionItemKey eCopyOptionItemKey, int i, int i2, int i3, int i4) {
        key = eCopyOptionItemKey;
        choiceType = ECopyOptionItemChoiceType.NumberRange;
        enabled = true;
        numberRange = new NumberRange();
        NumberRange numberRange2 = numberRange;
        numberRange2.min = i;
        numberRange2.max = i2;
        numberRange2.selectedValue = i3;
        numberRange2.defaultValue = i3;
        numberRange2.exceptionValue = i4;
    }

    ECopyOptionItem(ECopyOptionItemKey eCopyOptionItemKey, ArrayList<ERemoteOperation.ERemoteParam> arrayList, ERemoteOperation.ERemoteParam eRemoteParam) {
        key = eCopyOptionItemKey;
        choiceType = ECopyOptionItemChoiceType.ChoiceArray;
        choiceArray = new ChoiceArray();
        choiceArray.defaultChoice = 0;
        Iterator<ERemoteOperation.ERemoteParam> it = arrayList.iterator();
        while (it.hasNext()) {
            ERemoteOperation.ERemoteParam next = it.next();
            choiceArray.choices.add(ECopyOptionItemChoice.valueOf(key, next));
            if (next == eRemoteParam) {
                ChoiceArray choiceArray2 = choiceArray;
                choiceArray2.defaultChoice = choiceArray2.choices.size() - 1;
            }
        }
        ChoiceArray choiceArray3 = choiceArray;
        choiceArray3.selectedChoice = choiceArray3.defaultChoice;
        if (arrayList.size() > 1) {
            enabled = true;
        } else {
            enabled = false;
        }
    }

    ECopyOptionItem(ECopyOptionItem eCopyOptionItem) {
        key = eCopyOptionItem.key;
        choiceType = eCopyOptionItem.choiceType;
        enabled = eCopyOptionItem.enabled;
        isLocalOption = eCopyOptionItem.isLocalOption;
        if (choiceType == ECopyOptionItemChoiceType.ChoiceArray) {
            choiceArray = new ChoiceArray(eCopyOptionItem.choiceArray);
        } else {
            numberRange = new NumberRange(eCopyOptionItem.numberRange);
        }
    }

    public boolean equals(Object obj) {
        ECopyOptionItemChoiceType eCopyOptionItemChoiceType;
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof ECopyOptionItem)) {
            return false;
        }
        ECopyOptionItem eCopyOptionItem = (ECopyOptionItem) obj;
        if (key != eCopyOptionItem.key || (eCopyOptionItemChoiceType = choiceType) != eCopyOptionItem.choiceType || isLocalOption != eCopyOptionItem.isLocalOption) {
            return false;
        }
        if (eCopyOptionItemChoiceType == ECopyOptionItemChoiceType.ChoiceArray) {
            return choiceArray.equals(eCopyOptionItem.choiceArray);
        }
        return numberRange.equals(eCopyOptionItem.numberRange);
    }

    public enum ECopyOptionItemKey {
        ColorEffectsType(ERemoteOperation.ERemoteParam.color_effects_type),
        PrintMediaType(ERemoteOperation.ERemoteParam.print_media_type),
        PrintMediaSize(ERemoteOperation.ERemoteParam.print_media_size),
        PrintMediaSource(ERemoteOperation.ERemoteParam.print_media_source),
        PrintQuality(ERemoteOperation.ERemoteParam.print_quality),
        XDensity(ERemoteOperation.ERemoteParam.x_density),
        Copies(ERemoteOperation.ERemoteParam.copies),
        RepeatLayout(ERemoteOperation.ERemoteParam.layout),
        RemoveBackground(ERemoteOperation.ERemoteParam.x_remove_background),
        XCutLine(ERemoteOperation.ERemoteParam.x_cut_line),
        XCutLineStyle(ERemoteOperation.ERemoteParam.x_cut_line_style),
        XCutLineWeight(ERemoteOperation.ERemoteParam.x_cut_line_weight),
        InvalidKey(ERemoteOperation.ERemoteParam.x_null);

        ERemoteOperation.ERemoteParam param;

        private ECopyOptionItemKey(ERemoteOperation.ERemoteParam eRemoteParam) {
            param = eRemoteParam;
        }
    }

    public enum ECopyOptionItemChoice {
        ColorEffectsType_Color(ECopyOptionItemKey.ColorEffectsType, ERemoteOperation.ERemoteParam.color),
        ColorEffectsType_MonochromeGrayscale(ECopyOptionItemKey.ColorEffectsType, ERemoteOperation.ERemoteParam.monochrome_grayscale),
        PrintMediaSource_Top(ECopyOptionItemKey.PrintMediaSource, ERemoteOperation.ERemoteParam.top),
        PrintMediaSource_Bottom(ECopyOptionItemKey.PrintMediaSource, ERemoteOperation.ERemoteParam.bottom),
        PrintMediaSource_Rear(ECopyOptionItemKey.PrintMediaSource, ERemoteOperation.ERemoteParam.rear),
        PrintMediaSource_Manual(ECopyOptionItemKey.PrintMediaSource, ERemoteOperation.ERemoteParam.manual),
        PrintMediaType_Stationery(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.stationery),
        PrintMediaType_PhotographicHighGloss(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.photographic_high_gloss),
        PrintMediaType_Photographic(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.photographic),
        PrintMediaType_PhotographicSemiGloss(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.photographic_semi_gloss),
        PrintMediaType_PhotographicGlossy(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.photographic_glossy),
        PrintMediaType_CustomMediaTypeEpson44(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.custom_media_type_epson_44),
        PrintMediaType_PhotographicMatte(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.photographic_matte),
        PrintMediaType_StationeryCoated(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.stationery_coated),
        PrintMediaType_CustomMediaTypeEpson2A(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.custom_media_type_epson_2a),
        PrintMediaType_StationeryInkjet(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.stationery_inkjet),
        PrintMediaType_CustomMediaTypeEpson1B(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.custom_media_type_epson_1b),
        PrintMediaType_CustomMediaTypeEpson02(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.custom_media_type_epson_02),
        PrintMediaType_CustomMediaTypeEpson19(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.custom_media_type_epson_19),
        PrintMediaType_Lebals(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.labels),
        PrintMediaType_Envelope(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.envelope),
        PrintMediaType_DBLMEISHI_HALFGROSSY(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.custom_media_type_epson_47),
        PrintMediaType_HagakiAtena(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.custom_media_type_epson_20),
        PrintMediaType_BussnessPlain(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.custom_media_type_epson_39),
        PrintMediaType_StationeryHeavyweight(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.stationery_heavyweight),
        PrintMediaType_StationeryLetterhead(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.stationery_letterhead),
        PrintMediaType_BrightColorPlain(ECopyOptionItemKey.PrintMediaType, ERemoteOperation.ERemoteParam.custom_media_type_epson_46),
        PrintMediaSize_A4(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.iso_a4_210x297mm),
        PrintMediaSize_B4(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.jis_b4_257x364mm),
        PrintMediaSize_B5(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.jis_b5_182x257mm),
        PrintMediaSize_L(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.oe_photo_l_3_5x5in),
        PrintMediaSize_2L(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_5x7_5x7in),
        PrintMediaSize_Postcard(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.jpn_hagaki_100x148mm),
        PrintMediaSize_KG(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_index_4x6_4x6in),
        PrintMediaSize_8x10in(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_govt_letter_8x10in),
        PrintMediaSize_Letter(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_letter_8_5x11in),
        PrintMediaSize_Legal(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_legal_8_5x14in),
        PrintMediaSize_A5(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.iso_a5_148x210mm),
        PrintMediaSize_254x305mm(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.custom_4psize_254x305mm),
        PrintMediaSize_A3(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.iso_a3_297x420mm),
        PrintMediaSize_US_B(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_ledger_11x17in),
        PrintMediaSize_A6(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.iso_a6_105x148mm),
        PrintMediaSize_CHOU3(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.jpn_chou3_120x235mm),
        PrintMediaSize_CHOU4(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.jpn_chou4_90x205mm),
        PrintMediaSize_YOU1(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.custom_epson_18_120x176mm),
        PrintMediaSize_YOU3(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.custom_epson_1A_98x148mm),
        PrintMediaSize_YOU4(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.jpn_you4_105x235mm),
        PrintMediaSize_YOU2(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.iso_c6_114x162mm),
        PrintMediaSize_KAKU2(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.jpn_kaku2_240x332mm),
        PrintMediaSize_KAKU20(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.iso_c4_229x324mm),
        PrintMediaSize_MEISHI(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.custom_cardsize_55x91mm),
        PrintMediaSize_CARD(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.custom_creditcardsize_54x86mm),
        PrintMediaSize_Hivision(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.custom_hivision_101_6x180_6mm),
        PrintMediaSize_EnvelopeDL(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.iso_dl_110x220mm),
        PrintMediaSize_B6(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.jis_b6_128x182mm),
        PrintMediaSize_Executive(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_executive_7_25x10_5in),
        PrintMediaSize_8d5x13in(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_foolscap_8_5x13in),
        PrintMediaSize_11x14in(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_edp_11x14in),
        PrintMediaSize_EnvelopeNumber10(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_number_10_4_125x9_5in),
        PrintMediaSize_8K(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.om_8k_270x390mm),
        PrintMediaSize_16K(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.om_16k_195x270mm),
        PrintMediaSize_HalfLetter(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_invoice_5_5x8_5in),
        PrintMediaSize_IndianLegal215x345mm(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.custom_epson_indianlegal_215x345mm),
        PrintMediaSize_MexicoOficio8d5x13d4in(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.na_oficio_8_5x13_4in),
        PrintMediaSize_Oficio9_8d46x12d4in(ECopyOptionItemKey.PrintMediaSize, ERemoteOperation.ERemoteParam.om_folio_sp_215x315mm),
        PrintQuality_Economy(ECopyOptionItemKey.PrintQuality, ERemoteOperation.ERemoteParam.draft),
        PrintQuality_Normal(ECopyOptionItemKey.PrintQuality, ERemoteOperation.ERemoteParam.normal),
        PrintQuality_High(ECopyOptionItemKey.PrintQuality, ERemoteOperation.ERemoteParam.high),
        PrintQuality_Best(ECopyOptionItemKey.PrintQuality, ERemoteOperation.ERemoteParam.best),
        RepeatLayout_twoRepeat(ECopyOptionItemKey.RepeatLayout, ERemoteOperation.ERemoteParam.two_repeat),
        RepeatLayout_fourRepeat(ECopyOptionItemKey.RepeatLayout, ERemoteOperation.ERemoteParam.four_repeat),
        RepeatLayout_autoRepeat(ECopyOptionItemKey.RepeatLayout, ERemoteOperation.ERemoteParam.auto_repeat),
        XRemoveBackground_On(ECopyOptionItemKey.RemoveBackground, ERemoteOperation.ERemoteParam.on),
        XRemoveBackground_Off(ECopyOptionItemKey.RemoveBackground, ERemoteOperation.ERemoteParam.off),
        XCutLine_Dash(ECopyOptionItemKey.XCutLine, ERemoteOperation.ERemoteParam.dash),
        XCutLine_On(ECopyOptionItemKey.XCutLine, ERemoteOperation.ERemoteParam.on),
        XCutLine_Off(ECopyOptionItemKey.XCutLine, ERemoteOperation.ERemoteParam.off),
        XCutLineStyle_Dash(ECopyOptionItemKey.XCutLineStyle, ERemoteOperation.ERemoteParam.dash),
        XCutLineStyle_Dot(ECopyOptionItemKey.XCutLineStyle, ERemoteOperation.ERemoteParam.dot),
        XCutLineStyle_Continuous(ECopyOptionItemKey.XCutLineStyle, ERemoteOperation.ERemoteParam.continuous),
        XCutLineWidth_Dash(ECopyOptionItemKey.XCutLineWeight, ERemoteOperation.ERemoteParam.dash),
        XCutLineWidth_Thin(ECopyOptionItemKey.XCutLineWeight, ERemoteOperation.ERemoteParam.thin),
        XCutLineWidth_Medium(ECopyOptionItemKey.XCutLineWeight, ERemoteOperation.ERemoteParam.medium),
        XCutLineWidth_Thick(ECopyOptionItemKey.XCutLineWeight, ERemoteOperation.ERemoteParam.thick);

        ECopyOptionItemKey key;
        ERemoteOperation.ERemoteParam param;

        private ECopyOptionItemChoice(ECopyOptionItemKey eCopyOptionItemKey, ERemoteOperation.ERemoteParam eRemoteParam) {
            param = eRemoteParam;
        }

        public ERemoteOperation.ERemoteParam getParam() {
            return param;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:101:0x00bd, code lost:
            return PrintMediaSize_A6;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:103:0x00c0, code lost:
            return PrintMediaSize_US_B;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:105:0x00c3, code lost:
            return PrintMediaSize_A3;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:107:0x00c6, code lost:
            return PrintMediaSize_254x305mm;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:109:0x00c9, code lost:
            return PrintMediaSize_A5;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:111:0x00cc, code lost:
            return PrintMediaSize_Legal;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:113:0x00cf, code lost:
            return PrintMediaSize_Letter;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:115:0x00d2, code lost:
            return PrintMediaSize_8x10in;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:117:0x00d5, code lost:
            return PrintMediaSize_KG;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:119:0x00d8, code lost:
            return PrintMediaSize_Postcard;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:11:0x002d, code lost:
            return PrintMediaType_BrightColorPlain;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:121:0x00db, code lost:
            return PrintMediaSize_2L;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:123:0x00de, code lost:
            return PrintMediaSize_L;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:125:0x00e1, code lost:
            return PrintMediaSize_B5;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:127:0x00e4, code lost:
            return PrintMediaSize_B4;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:129:0x00e7, code lost:
            return PrintMediaSize_A4;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:131:0x00f0, code lost:
            switch(r2) {
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.top :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00fd;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.bottom :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00fa;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.rear :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00f7;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.manual :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00f4;
                default: goto L_0x00f3;
            };
         */
        /* JADX WARNING: Code restructure failed: missing block: B:133:0x00f6, code lost:
            return PrintMediaSource_Manual;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:135:0x00f9, code lost:
            return PrintMediaSource_Rear;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:137:0x00fc, code lost:
            return PrintMediaSource_Bottom;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:139:0x00ff, code lost:
            return PrintMediaSource_Top;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:13:0x0030, code lost:
            return PrintMediaType_StationeryLetterhead;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:141:0x0108, code lost:
            switch(r2) {
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.draft :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0115;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.normal :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0112;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.high :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x010f;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.best :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x010c;
                default: goto L_0x010b;
            };
         */
        /* JADX WARNING: Code restructure failed: missing block: B:143:0x010e, code lost:
            return PrintQuality_Best;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:145:0x0111, code lost:
            return PrintQuality_High;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:147:0x0114, code lost:
            return PrintQuality_Normal;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:149:0x0117, code lost:
            return PrintQuality_Economy;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:151:0x0120, code lost:
            switch(r2) {
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.two_repeat :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x012a;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.four_repeat :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0127;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.auto_repeat :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0124;
                default: goto L_0x0123;
            };
         */
        /* JADX WARNING: Code restructure failed: missing block: B:153:0x0126, code lost:
            return RepeatLayout_autoRepeat;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:155:0x0129, code lost:
            return RepeatLayout_fourRepeat;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:157:0x012c, code lost:
            return RepeatLayout_twoRepeat;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:159:0x0135, code lost:
            switch(r2) {
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.on :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x013c;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.off :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0139;
                default: goto L_0x0138;
            };
         */
        /* JADX WARNING: Code restructure failed: missing block: B:15:0x0033, code lost:
            return PrintMediaType_StationeryHeavyweight;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:161:0x013b, code lost:
            return XRemoveBackground_Off;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:163:0x013e, code lost:
            return XRemoveBackground_On;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:165:0x0147, code lost:
            switch(r2) {
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.on :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0151;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.off :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x014e;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.x_null :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x014b;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.dash :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x014b;
                default: goto L_0x014a;
            };
         */
        /* JADX WARNING: Code restructure failed: missing block: B:167:0x014d, code lost:
            return XCutLine_Dash;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:169:0x0150, code lost:
            return XCutLine_Off;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:171:0x0153, code lost:
            return XCutLine_On;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:173:0x015c, code lost:
            switch(r2) {
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.x_null :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0166;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.dash :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0166;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.dot :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0163;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.continuous :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0160;
                default: goto L_0x015f;
            };
         */
        /* JADX WARNING: Code restructure failed: missing block: B:175:0x0162, code lost:
            return XCutLineStyle_Continuous;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:177:0x0165, code lost:
            return XCutLineStyle_Dot;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:179:0x0168, code lost:
            return XCutLineStyle_Dash;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:17:0x0036, code lost:
            return PrintMediaType_BussnessPlain;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:181:0x0171, code lost:
            switch(r2) {
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.x_null :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x017e;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.dash :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x017e;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.dot :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0174;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.continuous :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0174;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.thin :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x017b;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.medium :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0178;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.thick :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0175;
                default: goto L_0x0174;
            };
         */
        /* JADX WARNING: Code restructure failed: missing block: B:183:0x0177, code lost:
            return XCutLineWidth_Thick;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:185:0x017a, code lost:
            return XCutLineWidth_Medium;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:187:0x017d, code lost:
            return XCutLineWidth_Thin;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:189:0x0180, code lost:
            return XCutLineWidth_Dash;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:191:?, code lost:
            return null;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:19:0x0039, code lost:
            return PrintMediaType_HagakiAtena;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:21:0x003c, code lost:
            return PrintMediaType_DBLMEISHI_HALFGROSSY;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:23:0x003f, code lost:
            return PrintMediaType_Envelope;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:25:0x0042, code lost:
            return PrintMediaType_Lebals;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:27:0x0045, code lost:
            return PrintMediaType_CustomMediaTypeEpson19;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:29:0x0048, code lost:
            return PrintMediaType_CustomMediaTypeEpson02;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:31:0x004b, code lost:
            return PrintMediaType_CustomMediaTypeEpson1B;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:33:0x004e, code lost:
            return PrintMediaType_StationeryInkjet;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:35:0x0051, code lost:
            return PrintMediaType_CustomMediaTypeEpson2A;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:37:0x0054, code lost:
            return PrintMediaType_StationeryCoated;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:39:0x0057, code lost:
            return PrintMediaType_PhotographicMatte;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:41:0x005a, code lost:
            return PrintMediaType_CustomMediaTypeEpson44;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:43:0x005d, code lost:
            return PrintMediaType_PhotographicGlossy;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:45:0x0060, code lost:
            return PrintMediaType_PhotographicSemiGloss;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:47:0x0063, code lost:
            return PrintMediaType_Photographic;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:49:0x0066, code lost:
            return PrintMediaType_PhotographicHighGloss;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:51:0x0069, code lost:
            return PrintMediaType_Stationery;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:53:0x0072, code lost:
            switch(r2) {
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.iso_a4_210x297mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00e5;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.jis_b4_257x364mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00e2;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.jis_b5_182x257mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00df;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.oe_photo_l_3_5x5in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00dc;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_5x7_5x7in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00d9;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.jpn_hagaki_100x148mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00d6;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_index_4x6_4x6in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00d3;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_govt_letter_8x10in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00d0;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_letter_8_5x11in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00cd;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_legal_8_5x14in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00ca;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.iso_a5_148x210mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00c7;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_4psize_254x305mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00c4;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.iso_a3_297x420mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00c1;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_ledger_11x17in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00be;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.iso_a6_105x148mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00bb;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.jpn_chou3_120x235mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00b8;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.jpn_chou4_90x205mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00b5;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_epson_18_120x176mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00b2;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_epson_1A_98x148mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00af;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.jpn_you4_105x235mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00ac;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.iso_c6_114x162mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00a9;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.jpn_kaku2_240x332mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00a6;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.iso_c4_229x324mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00a3;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_cardsize_55x91mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x00a0;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_creditcardsize_54x86mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x009d;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_hivision_101_6x180_6mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x009a;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.iso_dl_110x220mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0097;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.jis_b6_128x182mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0094;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_executive_7_25x10_5in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0091;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_foolscap_8_5x13in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x008e;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_edp_11x14in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x008b;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_number_10_4_125x9_5in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0088;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.om_8k_270x390mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0085;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.om_16k_195x270mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0082;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_invoice_5_5x8_5in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x007f;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_epson_indianlegal_215x345mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x007c;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.na_oficio_8_5x13_4in :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0079;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.om_folio_sp_215x315mm :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0076;
                default: goto L_0x0075;
            };
         */
        /* JADX WARNING: Code restructure failed: missing block: B:55:0x0078, code lost:
            return PrintMediaSize_Oficio9_8d46x12d4in;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:57:0x007b, code lost:
            return PrintMediaSize_MexicoOficio8d5x13d4in;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:59:0x007e, code lost:
            return PrintMediaSize_IndianLegal215x345mm;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:61:0x0081, code lost:
            return PrintMediaSize_HalfLetter;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:63:0x0084, code lost:
            return PrintMediaSize_16K;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:65:0x0087, code lost:
            return PrintMediaSize_8K;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:67:0x008a, code lost:
            return PrintMediaSize_EnvelopeNumber10;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:69:0x008d, code lost:
            return PrintMediaSize_11x14in;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:71:0x0090, code lost:
            return PrintMediaSize_8d5x13in;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:73:0x0093, code lost:
            return PrintMediaSize_Executive;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:75:0x0096, code lost:
            return PrintMediaSize_B6;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:77:0x0099, code lost:
            return PrintMediaSize_EnvelopeDL;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:79:0x009c, code lost:
            return PrintMediaSize_Hivision;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:81:0x009f, code lost:
            return PrintMediaSize_CARD;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:83:0x00a2, code lost:
            return PrintMediaSize_MEISHI;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:85:0x00a5, code lost:
            return PrintMediaSize_KAKU20;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:87:0x00a8, code lost:
            return PrintMediaSize_KAKU2;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:89:0x00ab, code lost:
            return PrintMediaSize_YOU2;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:91:0x00ae, code lost:
            return PrintMediaSize_YOU4;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:93:0x00b1, code lost:
            return PrintMediaSize_YOU3;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:95:0x00b4, code lost:
            return PrintMediaSize_YOU1;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:97:0x00b7, code lost:
            return PrintMediaSize_CHOU4;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:99:0x00ba, code lost:
            return PrintMediaSize_CHOU3;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:9:0x0027, code lost:
            switch(r2) {
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.stationery :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0067;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.photographic_high_gloss :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0064;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.photographic :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0061;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.photographic_semi_gloss :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x005e;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.photographic_glossy :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x005b;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_media_type_epson_44 :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0058;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.photographic_matte :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0055;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.stationery_coated :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0052;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_media_type_epson_2a :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x004f;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.stationery_inkjet :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x004c;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_media_type_epson_1b :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0049;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_media_type_epson_02 :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0046;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_media_type_epson_19 :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0043;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.labels :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0040;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.envelope :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x003d;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_media_type_epson_47 :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x003a;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_media_type_epson_20 :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0037;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_media_type_epson_39 :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0034;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.stationery_heavyweight :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x0031;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.stationery_letterhead :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x002e;
                case epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam.custom_media_type_epson_46 :epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam: goto L_0x002b;
                default: goto L_0x002a;
            };
         */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public static epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.ECopyOptionItemChoice valueOf(epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.ECopyOptionItemKey r1, epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation.ERemoteParam r2) {
            /*
                int[] r0 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f394xbdfa6ebc
                int r1 = r1.ordinal()
                r1 = r0[r1]
                switch(r1) {
                    case 1: goto L_0x000d;
                    case 2: goto L_0x001f;
                    case 3: goto L_0x006a;
                    case 4: goto L_0x00e8;
                    case 5: goto L_0x0100;
                    case 6: goto L_0x0118;
                    case 7: goto L_0x012d;
                    case 8: goto L_0x013f;
                    case 9: goto L_0x0154;
                    case 10: goto L_0x0169;
                    default: goto L_0x000b;
                }
            L_0x000b:
                goto L_0x0181
            L_0x000d:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r0 = r2.ordinal()
                r1 = r1[r0]
                switch(r1) {
                    case 1: goto L_0x001c;
                    case 2: goto L_0x0019;
                    default: goto L_0x0018;
                }
            L_0x0018:
                goto L_0x001f
            L_0x0019:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = ColorEffectsType_MonochromeGrayscale
                return r1
            L_0x001c:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = ColorEffectsType_Color
                return r1
            L_0x001f:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r0 = r2.ordinal()
                r1 = r1[r0]
                switch(r1) {
                    case 3: goto L_0x0067;
                    case 4: goto L_0x0064;
                    case 5: goto L_0x0061;
                    case 6: goto L_0x005e;
                    case 7: goto L_0x005b;
                    case 8: goto L_0x0058;
                    case 9: goto L_0x0055;
                    case 10: goto L_0x0052;
                    case 11: goto L_0x004f;
                    case 12: goto L_0x004c;
                    case 13: goto L_0x0049;
                    case 14: goto L_0x0046;
                    case 15: goto L_0x0043;
                    case 16: goto L_0x0040;
                    case 17: goto L_0x003d;
                    case 18: goto L_0x003a;
                    case 19: goto L_0x0037;
                    case 20: goto L_0x0034;
                    case 21: goto L_0x0031;
                    case 22: goto L_0x002e;
                    case 23: goto L_0x002b;
                    default: goto L_0x002a;
                }
            L_0x002a:
                goto L_0x006a
            L_0x002b:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_BrightColorPlain
                return r1
            L_0x002e:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_StationeryLetterhead
                return r1
            L_0x0031:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_StationeryHeavyweight
                return r1
            L_0x0034:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_BussnessPlain
                return r1
            L_0x0037:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_HagakiAtena
                return r1
            L_0x003a:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_DBLMEISHI_HALFGROSSY
                return r1
            L_0x003d:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_Envelope
                return r1
            L_0x0040:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_Lebals
                return r1
            L_0x0043:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_CustomMediaTypeEpson19
                return r1
            L_0x0046:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_CustomMediaTypeEpson02
                return r1
            L_0x0049:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_CustomMediaTypeEpson1B
                return r1
            L_0x004c:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_StationeryInkjet
                return r1
            L_0x004f:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_CustomMediaTypeEpson2A
                return r1
            L_0x0052:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_StationeryCoated
                return r1
            L_0x0055:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_PhotographicMatte
                return r1
            L_0x0058:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_CustomMediaTypeEpson44
                return r1
            L_0x005b:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_PhotographicGlossy
                return r1
            L_0x005e:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_PhotographicSemiGloss
                return r1
            L_0x0061:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_Photographic
                return r1
            L_0x0064:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_PhotographicHighGloss
                return r1
            L_0x0067:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaType_Stationery
                return r1
            L_0x006a:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r0 = r2.ordinal()
                r1 = r1[r0]
                switch(r1) {
                    case 24: goto L_0x00e5;
                    case 25: goto L_0x00e2;
                    case 26: goto L_0x00df;
                    case 27: goto L_0x00dc;
                    case 28: goto L_0x00d9;
                    case 29: goto L_0x00d6;
                    case 30: goto L_0x00d3;
                    case 31: goto L_0x00d0;
                    case 32: goto L_0x00cd;
                    case 33: goto L_0x00ca;
                    case 34: goto L_0x00c7;
                    case 35: goto L_0x00c4;
                    case 36: goto L_0x00c1;
                    case 37: goto L_0x00be;
                    case 38: goto L_0x00bb;
                    case 39: goto L_0x00b8;
                    case 40: goto L_0x00b5;
                    case 41: goto L_0x00b2;
                    case 42: goto L_0x00af;
                    case 43: goto L_0x00ac;
                    case 44: goto L_0x00a9;
                    case 45: goto L_0x00a6;
                    case 46: goto L_0x00a3;
                    case 47: goto L_0x00a0;
                    case 48: goto L_0x009d;
                    case 49: goto L_0x009a;
                    case 50: goto L_0x0097;
                    case 51: goto L_0x0094;
                    case 52: goto L_0x0091;
                    case 53: goto L_0x008e;
                    case 54: goto L_0x008b;
                    case 55: goto L_0x0088;
                    case 56: goto L_0x0085;
                    case 57: goto L_0x0082;
                    case 58: goto L_0x007f;
                    case 59: goto L_0x007c;
                    case 60: goto L_0x0079;
                    case 61: goto L_0x0076;
                    default: goto L_0x0075;
                }
            L_0x0075:
                goto L_0x00e8
            L_0x0076:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_Oficio9_8d46x12d4in
                return r1
            L_0x0079:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_MexicoOficio8d5x13d4in
                return r1
            L_0x007c:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_IndianLegal215x345mm
                return r1
            L_0x007f:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_HalfLetter
                return r1
            L_0x0082:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_16K
                return r1
            L_0x0085:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_8K
                return r1
            L_0x0088:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_EnvelopeNumber10
                return r1
            L_0x008b:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_11x14in
                return r1
            L_0x008e:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_8d5x13in
                return r1
            L_0x0091:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_Executive
                return r1
            L_0x0094:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_B6
                return r1
            L_0x0097:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_EnvelopeDL
                return r1
            L_0x009a:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_Hivision
                return r1
            L_0x009d:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_CARD
                return r1
            L_0x00a0:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_MEISHI
                return r1
            L_0x00a3:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_KAKU20
                return r1
            L_0x00a6:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_KAKU2
                return r1
            L_0x00a9:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_YOU2
                return r1
            L_0x00ac:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_YOU4
                return r1
            L_0x00af:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_YOU3
                return r1
            L_0x00b2:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_YOU1
                return r1
            L_0x00b5:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_CHOU4
                return r1
            L_0x00b8:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_CHOU3
                return r1
            L_0x00bb:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_A6
                return r1
            L_0x00be:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_US_B
                return r1
            L_0x00c1:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_A3
                return r1
            L_0x00c4:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_254x305mm
                return r1
            L_0x00c7:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_A5
                return r1
            L_0x00ca:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_Legal
                return r1
            L_0x00cd:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_Letter
                return r1
            L_0x00d0:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_8x10in
                return r1
            L_0x00d3:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_KG
                return r1
            L_0x00d6:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_Postcard
                return r1
            L_0x00d9:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_2L
                return r1
            L_0x00dc:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_L
                return r1
            L_0x00df:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_B5
                return r1
            L_0x00e2:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_B4
                return r1
            L_0x00e5:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSize_A4
                return r1
            L_0x00e8:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r0 = r2.ordinal()
                r1 = r1[r0]
                switch(r1) {
                    case 62: goto L_0x00fd;
                    case 63: goto L_0x00fa;
                    case 64: goto L_0x00f7;
                    case 65: goto L_0x00f4;
                    default: goto L_0x00f3;
                }
            L_0x00f3:
                goto L_0x0100
            L_0x00f4:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSource_Manual
                return r1
            L_0x00f7:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSource_Rear
                return r1
            L_0x00fa:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSource_Bottom
                return r1
            L_0x00fd:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintMediaSource_Top
                return r1
            L_0x0100:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r0 = r2.ordinal()
                r1 = r1[r0]
                switch(r1) {
                    case 66: goto L_0x0115;
                    case 67: goto L_0x0112;
                    case 68: goto L_0x010f;
                    case 69: goto L_0x010c;
                    default: goto L_0x010b;
                }
            L_0x010b:
                goto L_0x0118
            L_0x010c:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintQuality_Best
                return r1
            L_0x010f:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintQuality_High
                return r1
            L_0x0112:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintQuality_Normal
                return r1
            L_0x0115:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = PrintQuality_Economy
                return r1
            L_0x0118:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r0 = r2.ordinal()
                r1 = r1[r0]
                switch(r1) {
                    case 70: goto L_0x012a;
                    case 71: goto L_0x0127;
                    case 72: goto L_0x0124;
                    default: goto L_0x0123;
                }
            L_0x0123:
                goto L_0x012d
            L_0x0124:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = RepeatLayout_autoRepeat
                return r1
            L_0x0127:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = RepeatLayout_fourRepeat
                return r1
            L_0x012a:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = RepeatLayout_twoRepeat
                return r1
            L_0x012d:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r0 = r2.ordinal()
                r1 = r1[r0]
                switch(r1) {
                    case 73: goto L_0x013c;
                    case 74: goto L_0x0139;
                    default: goto L_0x0138;
                }
            L_0x0138:
                goto L_0x013f
            L_0x0139:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XRemoveBackground_Off
                return r1
            L_0x013c:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XRemoveBackground_On
                return r1
            L_0x013f:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r0 = r2.ordinal()
                r1 = r1[r0]
                switch(r1) {
                    case 73: goto L_0x0151;
                    case 74: goto L_0x014e;
                    case 75: goto L_0x014b;
                    case 76: goto L_0x014b;
                    default: goto L_0x014a;
                }
            L_0x014a:
                goto L_0x0154
            L_0x014b:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLine_Dash
                return r1
            L_0x014e:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLine_Off
                return r1
            L_0x0151:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLine_On
                return r1
            L_0x0154:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r0 = r2.ordinal()
                r1 = r1[r0]
                switch(r1) {
                    case 75: goto L_0x0166;
                    case 76: goto L_0x0166;
                    case 77: goto L_0x0163;
                    case 78: goto L_0x0160;
                    default: goto L_0x015f;
                }
            L_0x015f:
                goto L_0x0169
            L_0x0160:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLineStyle_Continuous
                return r1
            L_0x0163:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLineStyle_Dot
                return r1
            L_0x0166:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLineStyle_Dash
                return r1
            L_0x0169:
                int[] r1 = epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.C22652.f395xa3b36046
                int r2 = r2.ordinal()
                r1 = r1[r2]
                switch(r1) {
                    case 75: goto L_0x017e;
                    case 76: goto L_0x017e;
                    case 77: goto L_0x0174;
                    case 78: goto L_0x0174;
                    case 79: goto L_0x017b;
                    case 80: goto L_0x0178;
                    case 81: goto L_0x0175;
                    default: goto L_0x0174;
                }
            L_0x0174:
                goto L_0x0181
            L_0x0175:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLineWidth_Thick
                return r1
            L_0x0178:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLineWidth_Medium
                return r1
            L_0x017b:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLineWidth_Thin
                return r1
            L_0x017e:
                epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r1 = XCutLineWidth_Dash
                return r1
            L_0x0181:
                r1 = 0
                return r1
            */
            throw new UnsupportedOperationException("Method not decompiled: epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.ECopyOptionItemChoice.valueOf(epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemKey, epson.print.rpcopy.Component.eremoteoperation.ERemoteOperation$ERemoteParam):epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice");
        }
    }

    public ECopyOptionItemKey getKey() {
        return key;
    }

    public boolean isEnabled() {
        return enabled;
    }

    public ECopyOptionItemChoiceType getChoiceType() {
        return choiceType;
    }

    public int getMinimumValue() {
        return numberRange.min;
    }

    public int getMaximumValue() {
        return numberRange.max;
    }

    public int getDefaultValue() {
        return numberRange.defaultValue;
    }

    public int getSelectedValue() {
        return numberRange.selectedValue;
    }

    public void selectValue(int i) {
        NumberRange numberRange2 = numberRange;
        if (i != numberRange2.exceptionValue) {
            i = Math.min(Math.max(numberRange.min, i), numberRange.max);
        }
        numberRange2.selectedValue = i;
    }

    public ArrayList<ECopyOptionItemChoice> getSelectableChoices() {
        try {
            return choiceArray.choices;
        } catch (IndexOutOfBoundsException unused) {
            return null;
        }
    }

    public ECopyOptionItemChoice getDefaultChoice() {
        try {
            return choiceArray.choices.get(choiceArray.defaultChoice);
        } catch (IndexOutOfBoundsException unused) {
            return null;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0016, code lost:
        return null;
     */
    /* JADX WARNING: Exception block dominator not found, dom blocks: [] */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public synchronized epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.ECopyOptionItemChoice getSelectedChoice() {
        /*
            r2 = this;
            monitor-enter(r2)
            epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ChoiceArray r0 = r2.choiceArray     // Catch:{ IndexOutOfBoundsException -> 0x0014, all -> 0x0011 }
            java.util.ArrayList<epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice> r0 = r0.choices     // Catch:{ IndexOutOfBoundsException -> 0x0014, all -> 0x0011 }
            epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ChoiceArray r1 = r2.choiceArray     // Catch:{ IndexOutOfBoundsException -> 0x0014, all -> 0x0011 }
            int r1 = r1.selectedChoice     // Catch:{ IndexOutOfBoundsException -> 0x0014, all -> 0x0011 }
            java.lang.Object r0 = r0.get(r1)     // Catch:{ IndexOutOfBoundsException -> 0x0014, all -> 0x0011 }
            epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice r0 = (epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.ECopyOptionItemChoice) r0     // Catch:{ IndexOutOfBoundsException -> 0x0014, all -> 0x0011 }
            monitor-exit(r2)
            return r0
        L_0x0011:
            r0 = move-exception
            monitor-exit(r2)
            throw r0
        L_0x0014:
            r0 = 0
            monitor-exit(r2)
            return r0
        */
        throw new UnsupportedOperationException("Method not decompiled: epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem.getSelectedChoice():epson.print.rpcopy.Component.ecopycomponent.ECopyOptionItem$ECopyOptionItemChoice");
    }

    public synchronized void selectChoice(ECopyOptionItemChoice eCopyOptionItemChoice) {
        int i = 0;
        Iterator<ECopyOptionItemChoice> it = choiceArray.choices.iterator();
        while (true) {
            if (!it.hasNext()) {
                break;
            } else if (it.next() == eCopyOptionItemChoice) {
                choiceArray.selectedChoice = i;
                break;
            } else {
                i++;
            }
        }
    }

    public synchronized void updateChoicesXCutLine() {
        if (ERemoteOperation.ERemoteParam.dash.equals(getSelectedChoice().getParam())) {
            if (choiceArray.choices.size() > 1) {
                choiceArray.choices.clear();
                choiceArray.choices.add(ECopyOptionItemChoice.XCutLine_Dash);
                choiceArray.selectedChoice = 0;
                choiceArray.defaultChoice = 0;
            }
        } else if (choiceArray.choices.indexOf(ECopyOptionItemChoice.XCutLine_Dash) != -1) {
            ECopyOptionItemChoice selectedChoice = getSelectedChoice();
            ECopyOptionItemChoice defaultChoice = getDefaultChoice();
            choiceArray.choices.remove(ECopyOptionItemChoice.XCutLine_Dash);
            choiceArray.selectedChoice = choiceArray.choices.indexOf(selectedChoice);
            choiceArray.defaultChoice = choiceArray.choices.indexOf(defaultChoice);
        }
        if (choiceArray.choices.size() > 1) {
            enabled = true;
        } else {
            enabled = false;
        }
    }

    static ERemoteOperation.ERemoteParam layoutOf(ECopyComponent.ECopyType eCopyType) {
        ERemoteOperation.ERemoteParam eRemoteParam = ERemoteOperation.ERemoteParam.standard;
        switch (eCopyType) {
            case Standard:
                return ERemoteOperation.ERemoteParam.standard;
            case Borderless:
                return ERemoteOperation.ERemoteParam.borderless;
            case A4_2up:
                return ERemoteOperation.ERemoteParam.two_up;
            case B5_2up:
                return ERemoteOperation.ERemoteParam.two_up;
            case A4_2up_Book:
                return ERemoteOperation.ERemoteParam.two_up_book;
            case B5_2up_Book:
                return ERemoteOperation.ERemoteParam.two_up_book;
            case Mirror:
                return ERemoteOperation.ERemoteParam.mirror;
            case Photo:
                return ERemoteOperation.ERemoteParam.standard;
            default:
                return eRemoteParam;
        }
    }

    static ECopyOptionItemKey key(ERemoteOperation.ERemoteParam eRemoteParam) {
        ECopyOptionItemKey eCopyOptionItemKey = ECopyOptionItemKey.InvalidKey;
        switch (eRemoteParam) {
            case color_effects_type:
                return ECopyOptionItemKey.ColorEffectsType;
            case copies:
                return ECopyOptionItemKey.Copies;
            case print_media_size:
                return ECopyOptionItemKey.PrintMediaSize;
            case print_media_source:
                return ECopyOptionItemKey.PrintMediaSource;
            case print_media_type:
                return ECopyOptionItemKey.PrintMediaType;
            case print_quality:
                return ECopyOptionItemKey.PrintQuality;
            case x_density:
                return ECopyOptionItemKey.XDensity;
            case layout:
                return ECopyOptionItemKey.RepeatLayout;
            case x_remove_background:
                return ECopyOptionItemKey.RemoveBackground;
            case x_cut_line:
                return ECopyOptionItemKey.XCutLine;
            case x_cut_line_style:
                return ECopyOptionItemKey.XCutLineStyle;
            case x_cut_line_weight:
                return ECopyOptionItemKey.XCutLineWeight;
            default:
                return eCopyOptionItemKey;
        }
    }

    static ECopyOptionItem createOptionItem(ERemoteOperation.ERemoteParam eRemoteParam, ERemoteCopy.ERemoteCopyOptionsResult eRemoteCopyOptionsResult) {
        boolean z;
        ArrayList<ERemoteOperation.ERemoteParam> parameter_options = eRemoteCopyOptionsResult.parameter_options(eRemoteParam);
        ERemoteOperation.ERemoteParam parameter_default = eRemoteCopyOptionsResult.parameter_default(eRemoteParam);
        Iterator<ERemoteOperation.ERemoteParam> it = parameter_options.iterator();
        while (true) {
            if (it.hasNext()) {
                if (parameter_default.equals(it.next())) {
                    z = true;
                    break;
                }
            } else {
                z = false;
                break;
            }
        }
        if (!z) {
            parameter_options.add(parameter_default);
        }
        return new ECopyOptionItem(key(eRemoteParam), parameter_options, parameter_default);
    }

    static ECopyOptionItem createLocalOptionItem(ERemoteOperation.ERemoteParam eRemoteParam, ERemoteCopy.ERemoteCopyOptionsResult eRemoteCopyOptionsResult) {
        ECopyOptionItem eCopyOptionItem = new ECopyOptionItem(key(eRemoteParam), eRemoteCopyOptionsResult.local_options(eRemoteParam), eRemoteCopyOptionsResult.local_default(eRemoteParam));
        eCopyOptionItem.isLocalOption = true;
        return eCopyOptionItem;
    }

    static ECopyOptionItem createScaleOptionItem(ERemoteOperation.ERemoteParam eRemoteParam, ERemoteCopy.ERemoteCopyOptionsResult eRemoteCopyOptionsResult) {
        ArrayList<ERemoteOperation.ERemoteParam> parameter_options = eRemoteCopyOptionsResult.parameter_options(ERemoteOperation.ERemoteParam.print_media_size);
        eRemoteCopyOptionsResult.getClass();
        ECopyOptionItem eCopyOptionItem = new ECopyOptionItem(key(eRemoteParam), new ERemoteCopy.ERemoteCopyOptionsResult.ScaleOptions(parameter_options).scale_options(), eRemoteCopyOptionsResult.local_default(eRemoteParam));
        eCopyOptionItem.isLocalOption = true;
        return eCopyOptionItem;
    }

    static ECopyOptionItem createLocalOptionItem(ERemoteOperation.ERemoteParam eRemoteParam, int i, int i2, int i3) {
        ECopyOptionItem eCopyOptionItem = new ECopyOptionItem(key(eRemoteParam), i, i2, i3, DefaultExceptionValue);
        eCopyOptionItem.isLocalOption = true;
        return eCopyOptionItem;
    }
}
