package epson.print.storage.gdrivev3;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Typeface;
import android.os.Build;
import android.os.Bundle;
import android.support.p000v4.app.FragmentManager;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.epson.iprint.prtlogger.PrintLog;
import com.epson.iprint.storage.ConfirmCancelDialog;
import com.epson.iprint.storage.LocalProgressDialog;
import com.epson.iprint.storage.OneButtonDialogFragment;
import com.epson.iprint.storage.StorageProcessDownloadActivity;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedList;

import epson.print.ActivityIACommon;
import epson.print.R;


public class ListAndDownloadActivity extends ActivityIACommon implements ActivityWrapper, GoogleDownloadContract.View, OneButtonDialogFragment.DialogCallback, ConfirmCancelDialog.DialogCancelListener {
    private static final String DIALOG_TAG_CONFIRM_CANCEL = "confirm-cancel";
    private static final String DIALOG_TAG_DOWNLOAD_FAILED = "download_failed";
    private static final String DIALOG_TAG_OFFLINE_ERROR = "offline_error";
    private static final String DIALOG_TAG_SIGN_IN_FAILED = "sign-in_failed";
    private static final String FRAGMENT_TAG_PROGRESS = "fragment-progress";
    private static final int REQUEST_CODE_CHECK_PLAY_SERVICE = 11;
    private static final int REQUEST_CODE_DOWNLOAD_PREVIEW_END = 12;
    private static final int REQUEST_CODE_SIGN_IN = 10;
    private static final int REQUEST_CODE_SIGN_IN_ADD_SCOPE = 13;
    private boolean mActivityForeground;
    private FileListAdapter mFileListAdapter;
    private LinkedList<Runnable> mForegroundRunnableList;
    private GoogleDownloadContract.UserActionListener mGoogleDownloadPresenter;
    private boolean mIsDownloadInterruption = false;
    private ListView mListView;
    private int mPosition = 0;
    private TextView mSignInMessage;
    private boolean mSignInOutButtonEnabled;
    private int mSignInOutButtonType;
    private IprintGoogleSignIn.StartActivityResultCallback mSignInStartActivityCallback;

    @NonNull
    public Activity getActivity() {
        return this;
    }

    @NonNull
    public ActivityWrapper getActivityWrapper() {
        return this;
    }

    public int getPlayServiceRequestCode() {
        return 11;
    }

    public int getSingInAddScopeRequestCode() {
        return 13;
    }

    protected void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        setContentView(R.layout.activity_list_and_download);
        setActionBar(getString(R.string.google_drive), true);
        mGoogleDownloadPresenter = Injection.provideDownloadPresenter(this);
        mSignInOutButtonEnabled = true;
        mForegroundRunnableList = new LinkedList<>();
        mListView = (ListView) findViewById(16908298);
        mListView.setCacheColorHint(0);
        mFileListAdapter = new FileListAdapter(getApplicationContext());
        mListView.setAdapter(mFileListAdapter);
        mListView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            public void onItemClick(AdapterView<?> adapterView, View view, int i, long j) {
                int unused = ListAndDownloadActivity.mPosition = i;
                localOnItemClick(i);
            }
        });
        mSignInMessage = (TextView) findViewById(16908292);
        mSignInMessage.setText(R.string.sign_in_request);
        mSignInMessage.setTypeface((Typeface) null, 1);
        mSignInMessage.setTextSize(18.0f);
        if (bundle != null) {
            clearFragments();
        }
        mGoogleDownloadPresenter.initView();
    }

    private void clearFragments() {
        removeProgressIfExists();
        deleteAllDialog();
    }

    private void deleteAllDialog() {
        for (String dismissDialog : new String[]{DIALOG_TAG_SIGN_IN_FAILED, DIALOG_TAG_DOWNLOAD_FAILED, DIALOG_TAG_OFFLINE_ERROR, DIALOG_TAG_CONFIRM_CANCEL}) {
            dismissDialog(dismissDialog);
        }
    }

    private void dismissDialog(@NonNull final String str) {
        if (!mActivityForeground) {
            mForegroundRunnableList.addLast(new Runnable() {
                public void run() {
                    dismissDialog(str);
                }
            });
            return;
        }
        Fragment findFragmentByTag = getSupportFragmentManager().findFragmentByTag(str);
        if (findFragmentByTag != null) {
            ((DialogFragment) findFragmentByTag).dismiss();
        }
    }

    private void localOnItemClick(int i) {
        OnlineFile driveItem = mFileListAdapter.getDriveItem(i);
        if (driveItem != null) {
            mGoogleDownloadPresenter.itemSelected(driveItem);
        }
    }

    public boolean onOptionsItemSelected(MenuItem menuItem) {
        switch (menuItem.getItemId()) {
            case R.id.menu_signin /*2131231253*/:
                mGoogleDownloadPresenter.signInOrDisconnectClicked();
                return true;
            case R.id.menu_signout /*2131231254*/:
                mGoogleDownloadPresenter.signInOrDisconnectClicked();
                return true;
            default:
                return super.onOptionsItemSelected(menuItem);
        }
    }

    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_sign_inout, menu);
        if (mSignInOutButtonType == 0) {
            menu.removeItem(R.id.menu_signout);
            menu.findItem(R.id.menu_signin).setEnabled(mSignInOutButtonEnabled);
            return true;
        }
        menu.removeItem(R.id.menu_signin);
        menu.findItem(R.id.menu_signout).setEnabled(mSignInOutButtonEnabled);
        return true;
    }

    protected void onActivityResult(int i, int i2, Intent intent) {
        switch (i) {
            case 10:
                IprintGoogleSignIn.StartActivityResultCallback startActivityResultCallback = mSignInStartActivityCallback;
                if (startActivityResultCallback != null) {
                    startActivityResultCallback.onActivityResult(i2, intent);
                    mSignInStartActivityCallback = null;
                    return;
                }
                return;
            case 11:
                return;
            case 12:
                mGoogleDownloadPresenter.onPreviewActivityEnd();
                return;
            case 13:
                mGoogleDownloadPresenter.onAddScopeCompleted(i2 == -1);
                return;
            default:
                return;
        }
    }

    protected void onPostResume() {
        super.onPostResume();
        mActivityForeground = true;
        processForegroundList();
        mGoogleDownloadPresenter.activityOnResume();
    }

    private void processForegroundList() {
        Iterator it = mForegroundRunnableList.iterator();
        while (it.hasNext()) {
            it.remove();
            ((Runnable) it.next()).run();
        }
    }

    protected void onPause() {
        super.onPause();
        mGoogleDownloadPresenter.activityOnPause();
        mActivityForeground = false;
    }

    public void onBackPressed() {
        mGoogleDownloadPresenter.backKeyPressed();
    }

    public void requestSignIn(@NonNull Intent intent, @NonNull IprintGoogleSignIn.StartActivityResultCallback startActivityResultCallback) {
        mSignInStartActivityCallback = startActivityResultCallback;
        startActivityForResult(intent, 10);
    }

    public void setSignInButtonEnabled(boolean z) {
        invalidateOptionsMenu();
    }

    public void changeSignInOutButton(int i) {
        int i2 = 0;
        mSignInMessage.setVisibility(i == 0 ? 0 : 8);
        ListView listView = mListView;
        if (i == 0) {
            i2 = 8;
        }
        listView.setVisibility(i2);
        mSignInOutButtonType = i;
        invalidateOptionsMenu();
    }

    private void showErrorDialog(final int i, final String str) {
        if (!mActivityForeground) {
            mForegroundRunnableList.addLast(new Runnable() {
                public void run() {
                    showErrorDialog(i, str);
                }
            });
        } else {
            OneButtonDialogFragment.newInstance(i, str).show(getSupportFragmentManager(), str);
        }
    }

    public void showSignInFailDialog() {
        showErrorDialog(R.string.authenticate_error_mes, DIALOG_TAG_SIGN_IN_FAILED);
    }

    public void showDownloadErrorDialog() {
        showErrorDialog(R.string.download_error_mes, DIALOG_TAG_DOWNLOAD_FAILED);
    }

    public void showOfflineErrorDialog() {
        showErrorDialog(R.string.network_error_mes, DIALOG_TAG_OFFLINE_ERROR);
    }

    public void clearListItems() {
        mFileListAdapter.clearItems();
    }

    public void showProgress() {
        mSignInOutButtonEnabled = false;
        invalidateOptionsMenu();
        showProgressFragment(false, 0);
    }

    private void showProgressFragment(final boolean z, final int i) {
        if (!mActivityForeground) {
            mForegroundRunnableList.addLast(new Runnable() {
                public void run() {
                    showProgressFragment(z, i);
                }
            });
            return;
        }
        FragmentManager supportFragmentManager = getSupportFragmentManager();
        supportFragmentManager.beginTransaction().add(16908290, LocalProgressDialog.newInstance(z, i, DIALOG_TAG_CONFIRM_CANCEL), FRAGMENT_TAG_PROGRESS).commit();
    }

    public void showDownloadProgress() {
        mSignInOutButtonEnabled = false;
        invalidateOptionsMenu();
        showProgressFragment(true, R.string.downloading_notification);
    }

    public void dismissProgress() {
        dismissDialog(DIALOG_TAG_CONFIRM_CANCEL);
        removeProgressIfExists();
        mSignInOutButtonEnabled = true;
        invalidateOptionsMenu();
    }

    public void listFiles(@Nullable ArrayList<OnlineFile> arrayList) {
        if (arrayList == null) {
            clearListItems();
            showErrorDialog(R.string.unknow_error_mes, DIALOG_TAG_DOWNLOAD_FAILED);
            return;
        }
        mFileListAdapter.setDriveFile(arrayList);
    }

    public void startPreviewActivity(String str) {
        startActivityForResult(StorageProcessDownloadActivity.getPreviewIntent(str, getApplicationContext(), new PrintLog()), 12);
    }

    public void finishActivity() {
        finish();
    }

    public void buttonPressed(@Nullable String str) {
        if (str != null) {
            char c = 65535;
            int hashCode = str.hashCode();
            if (hashCode != -683930452) {
                if (hashCode != 156934100) {
                    if (hashCode == 366991495 && str.equals(DIALOG_TAG_SIGN_IN_FAILED)) {
                        c = 0;
                    }
                } else if (str.equals(DIALOG_TAG_DOWNLOAD_FAILED)) {
                    c = 1;
                }
            } else if (str.equals(DIALOG_TAG_OFFLINE_ERROR)) {
                c = 2;
            }
            switch (c) {
                case 0:
                    return;
                case 1:
                    return;
                case 2:
                    startActivity(new Intent("android.settings.WIRELESS_SETTINGS"));
                    finish();
                    return;
                default:
                    return;
            }
        }
    }

    public void cancel() {
        mGoogleDownloadPresenter.cancelDownload();
    }

    protected void onStop() {
        super.onStop();
        if (!mGoogleDownloadPresenter.isDownloading() || Build.VERSION.SDK_INT < 29) {
            mIsDownloadInterruption = false;
            return;
        }
        mIsDownloadInterruption = true;
        cancel();
    }

    protected void onRestart() {
        super.onRestart();
        if (mIsDownloadInterruption) {
            localOnItemClick(mPosition);
        }
        mIsDownloadInterruption = false;
    }

    private void removeProgressIfExists() {
        if (!mActivityForeground) {
            mForegroundRunnableList.addLast(new Runnable() {
                public void run() {
                    removeProgressIfExists();
                }
            });
            return;
        }
        FragmentManager supportFragmentManager = getSupportFragmentManager();
        Fragment findFragmentByTag = supportFragmentManager.findFragmentByTag(FRAGMENT_TAG_PROGRESS);
        if (findFragmentByTag != null) {
            supportFragmentManager.beginTransaction().remove(findFragmentByTag).commit();
        }
    }
}
