package epson.scan.lib;

import android.content.Context;

import java.io.Serializable;

import epson.print.R;

public class ScannerInfo implements Serializable {
    private int adfPaperGuide = 0;
    private int colorValue;
    private String commonDeviceName;
    private boolean densityStatus;
    private int densityValue;
    private String friendlyName;
    private int gammaValue;

    /* renamed from: ip */
    private String f413ip;
    private boolean isAdfDuplexRotaitonYes = false;
    private boolean isAdfDuplexYes = false;
    private boolean isReSearch;
    private int location;
    private int maxHeight;
    private int maxWidth;
    private String modelName;
    private int resolutionValue;
    private String scannerId;
    private int sizeValue;
    private int sourceValue;
    private int supportedAdfDuplex;
    private int supportedAdfHeight;
    private int supportedAdfWidth;
    private int supportedBasicHeight;
    private int supportedBasicResolution;
    private int supportedBasicWidth;
    private int[] supportedOptions;
    private int[] supportedResolutionList;
    private int supportedVersion;
    private int twoSidedScanningValue;
    private int version;

    public ScannerInfo() {
    }

    public ScannerInfo(ScannerInfo scannerInfo) {
        modelName = scannerInfo.getModelName();
        f413ip = scannerInfo.getIp();
        friendlyName = scannerInfo.getFriendlyName();
        scannerId = scannerInfo.getScannerId();
        colorValue = scannerInfo.getColorValue();
        densityStatus = scannerInfo.densityStatus;
        densityValue = scannerInfo.densityValue;
        gammaValue = scannerInfo.getGammaValue();
        sizeValue = scannerInfo.getSizeValue();
        isReSearch = scannerInfo.isReSearch();
        maxHeight = scannerInfo.getMaxHeight();
        maxWidth = scannerInfo.getMaxWidth();
        resolutionValue = scannerInfo.getResolutionValue();
        sourceValue = scannerInfo.getSourceValue();
        supportedAdfDuplex = scannerInfo.getSupportedAdfDuplex();
        supportedAdfHeight = scannerInfo.getSupportedAdfHeight();
        supportedAdfWidth = scannerInfo.getSupportedAdfWidth();
        supportedBasicHeight = scannerInfo.getSupportedBasicHeight();
        supportedBasicResolution = scannerInfo.getSupportedBasicResolution();
        supportedBasicWidth = scannerInfo.getSupportedBasicWidth();
        supportedOptions = scannerInfo.getSupportedOptions();
        supportedResolutionList = scannerInfo.getSupportedResolutionList();
        supportedVersion = scannerInfo.getSupportedVersion();
        twoSidedScanningValue = scannerInfo.getTwoSidedScanningValue();
        isAdfDuplexYes = scannerInfo.isAdfDuplexYes();
        isAdfDuplexRotaitonYes = scannerInfo.isAdfDuplexRotaitonYes();
        adfPaperGuide = scannerInfo.getAdfPaperGuide();
    }

    public String getModelName() {
        return modelName;
    }

    public boolean isModelNameEmpty() {
        String str = modelName;
        return str == null || str.isEmpty();
    }

    public void setModelName(String str) {
        modelName = str;
    }

    public String getIp() {
        return f413ip;
    }

    public void setIp(String str) {
        f413ip = str;
    }

    public String getFriendlyName() {
        return friendlyName;
    }

    public void setFriendlyName(String str) {
        friendlyName = str;
    }

    public String getScannerId() {
        return scannerId;
    }

    public void setScannerId(String str) {
        scannerId = str;
    }

    public String getCommonDeviceName() {
        return commonDeviceName;
    }

    public void setCommonDeviceName(String str) {
        commonDeviceName = str;
    }

    public int getLocation() {
        return location;
    }

    public void setLocation(int i) {
        location = i;
    }

    public int[] getSupportedOptions() {
        return supportedOptions;
    }

    public void setSupportedOptions(int[] iArr) {
        supportedOptions = iArr;
    }

    public int getVersion() {
        return version;
    }

    public void setVersion(int i) {
        version = i;
    }

    public String getResolutionName(Context context) {
        int resolutionValue2 = getResolutionValue();
        if (resolutionValue2 == 0) {
            return context.getString(R.string.str_blank);
        }
        return String.format(context.getString(R.string.str_settings_resolution), new Object[]{Integer.valueOf(resolutionValue2)});
    }

    public int getResolutionValue() {
        return resolutionValue;
    }

    public void setResolutionValue(int i) {
        resolutionValue = i;
    }

    public int getColorName() {
        switch (getColorValue()) {
            case 1:
                return R.string.str_settings_color_color;
            case 2:
                return R.string.str_settings_color_grayscale;
            case 3:
                return R.string.str_settings_color_monochrome;
            default:
                return R.string.str_blank;
        }
    }

    public int getColorValue() {
        return colorValue;
    }

    public void setColorValue(int i) {
        colorValue = i;
    }

    public int getSourceName() {
        switch (getSourceValue()) {
            case 0:
                return R.string.str_settings_source_doctable;
            case 1:
                return R.string.str_settings_source_adf;
            default:
                return R.string.str_blank;
        }
    }

    public int getSourceValue() {
        return sourceValue;
    }

    public void setSourceValue(int i) {
        sourceValue = i;
    }

    public int getTwoSidedScanningName() {
        switch (getTwoSidedScanningValue()) {
            case 0:
                return R.string.str_no;
            case 1:
                return R.string.str_yes;
            default:
                return R.string.str_blank;
        }
    }

    public int getTwoSidedScanningValue() {
        return twoSidedScanningValue;
    }

    public void setTwoSidedScanningValue(int i) {
        twoSidedScanningValue = i;
    }

    public int getDensityValue() {
        return densityValue;
    }

    public void setDensityValue(int i) {
        densityValue = i;
    }

    public boolean isDensityStatus() {
        return densityStatus;
    }

    public void setDensityStatus(boolean z) {
        densityStatus = z;
    }

    public int getGammaName() {
        switch (getGammaValue()) {
            case 0:
                return R.string.str_settings_gamma_10;
            case 1:
                return R.string.str_settings_gamma_18;
            default:
                return R.string.str_blank;
        }
    }

    public int getGammaValue() {
        return gammaValue;
    }

    public void setGammaValue(int i) {
        gammaValue = i;
    }

    public int getSizeValue() {
        return sizeValue;
    }

    public void setSizeValue(int i) {
        sizeValue = i;
    }

    public int getSupportedVersion() {
        return supportedVersion;
    }

    public void setSupportedVersion(int i) {
        supportedVersion = i;
    }

    public int getSupportedBasicResolution() {
        return supportedBasicResolution;
    }

    public void setSupportedBasicResolution(int i) {
        supportedBasicResolution = i;
    }

    public int getSupportedBasicHeight() {
        return supportedBasicHeight;
    }

    public void setSupportedBasicHeight(int i) {
        supportedBasicHeight = i;
    }

    public int getSupportedBasicWidth() {
        return supportedBasicWidth;
    }

    public void setSupportedBasicWidth(int i) {
        supportedBasicWidth = i;
    }

    public int getSupportedAdfHeight() {
        return supportedAdfHeight;
    }

    public void setSupportedAdfHeight(int i) {
        supportedAdfHeight = i;
    }

    public int getSupportedAdfWidth() {
        return supportedAdfWidth;
    }

    public void setSupportedAdfWidth(int i) {
        supportedAdfWidth = i;
    }

    public int getSupportedAdfDuplex() {
        return supportedAdfDuplex;
    }

    public void setSupportedAdfDuplex(int i) {
        supportedAdfDuplex = i;
    }

    public int[] getSupportedResolutionList() {
        return supportedResolutionList;
    }

    public void setSupportedResolutionList(int[] iArr) {
        supportedResolutionList = iArr;
    }

    public boolean isReSearch() {
        return isReSearch;
    }

    public void setReSearch(boolean z) {
        isReSearch = z;
    }

    public int getMaxWidth() {
        return maxWidth;
    }

    public void setMaxWidth(int i) {
        maxWidth = i;
    }

    public int getMaxHeight() {
        return maxHeight;
    }

    public void setMaxHeight(int i) {
        maxHeight = i;
    }

    public boolean isAdfDuplexYes() {
        return isAdfDuplexYes;
    }

    public void setAdfDuplexYes(boolean z) {
        isAdfDuplexYes = z;
    }

    public boolean isAdfDuplexRotaitonYes() {
        return isAdfDuplexRotaitonYes;
    }

    public void setAdfDuplexRotaitonYes(boolean z) {
        isAdfDuplexRotaitonYes = z;
    }

    public int getAdfPaperGuide() {
        return adfPaperGuide;
    }

    public void setAdfPaperGuide(int i) {
        adfPaperGuide = i;
    }

    @NonNull
    public static ScannerInfo getInstance() {
        ScannerInfo scannerInfo = new ScannerInfo();
        scannerInfo.setScannerId("");
        scannerInfo.setIp("");
        scannerInfo.setModelName("");
        scannerInfo.setLocation(1);
        scannerInfo.setCommonDeviceName("");
        scannerInfo.setSupportedOptions(new int[7]);
        scannerInfo.setSupportedResolutionList(new int[64]);
        return scannerInfo;
    }
}
